summaryrefslogtreecommitdiff
path: root/src/main/java/ftbsc/lll/exceptions
diff options
context:
space:
mode:
author zaaarf <zaaarf@proton.me>2023-03-25 19:33:51 +0100
committer zaaarf <zaaarf@proton.me>2023-03-25 19:33:51 +0100
commitcd21d0973dabe1c6fefe9bbf75a2ce097717e344 (patch)
tree210eff56be0255aee16d861f4fd17432906bb7a5 /src/main/java/ftbsc/lll/exceptions
parenta51cbceebc8642bb4c4a6e323bee1bf373328547 (diff)
fix: typo in condition, several exceptions, removed unused
Diffstat (limited to 'src/main/java/ftbsc/lll/exceptions')
-rw-r--r--src/main/java/ftbsc/lll/exceptions/TargetNotFoundException.java16
1 files changed, 13 insertions, 3 deletions
diff --git a/src/main/java/ftbsc/lll/exceptions/TargetNotFoundException.java b/src/main/java/ftbsc/lll/exceptions/TargetNotFoundException.java
index 45819bf..e3384b8 100644
--- a/src/main/java/ftbsc/lll/exceptions/TargetNotFoundException.java
+++ b/src/main/java/ftbsc/lll/exceptions/TargetNotFoundException.java
@@ -8,9 +8,19 @@ public class TargetNotFoundException extends RuntimeException {
/**
* Constructs a new target not found exception for the specified method stub.
* @param type the type of element being sought (class, method, etc.)
* @param stub the stub's name (and descriptor possibly)
*/
- public TargetNotFoundException(String type, String stub) {
- super(String.format("Could not find target %s %s.", type, stub));
+ public TargetNotFoundException(String type, String member) {
+ super(String.format("Could not find target %s %s.", type, member));
+ }
+
+ /**
+ * Constructs a new target not found exception for the specified method stub.
+ * @param type the type of element being sought (class, method, etc.)
+ * @param member the stub's name (and descriptor possibly)
+ * @param parent the parent of the member
+ */
+ public TargetNotFoundException(String type, String member, String parent) {
+ super(String.format("Could not find target %s %s in class %s.", type, member, parent));
}
}
@@ -8,9 +8,19 @@ public class TargetNotFoundException extends RuntimeException {
* Constructs a new target not found exception for the specified method stub.
* @param type the type of element being sought (class, method, etc.)
- * @param stub the stub's name (and descriptor possibly)
+ * @param member the stub's name (and descriptor possibly)
*/